'use client'

import { useState } from 'react'
import { FiSave, FiUser, FiLock, FiMail } from 'react-icons/fi'
import { useRouter } from 'next/navigation'
import DashboardLayout from '@/components/layout/DashboardLayout'
import { staffService } from '@/services/api'
import { useUser } from '@/contexts/UserContext'
import Modal from '@/components/ui/Modal'

export default function AddStaffPage() {
  const [formData, setFormData] = useState({
    name: '',
    email: '',
    password: '',
    password_confirmation: '',
    role: 'staff'
  })
  const [loading, setLoading] = useState(false)
  const [error, setError] = useState<string | null>(null)
  const [success, setSuccess] = useState<string | null>(null)
  const { user } = useUser()
  const router = useRouter()

  const handleSubmit = async (e: React.FormEvent) => {
    e.preventDefault()
    setLoading(true)
    setError(null)
    
    try {
      if (!user?.token) throw new Error('Oturum açık değil')
      
      await staffService.create({
        name: formData.name,
        email: formData.email,
        password: formData.password,
        password_confirmation: formData.password_confirmation
      }, user.token)

      setSuccess('Personel başarıyla eklendi')
      setTimeout(() => router.push('/dashboard/staff'), 2000)
    } catch (err: any) {
      setError(err.response?.data?.message || 'Bir hata oluştu')
    } finally {
      setLoading(false)
    }
  }

  return (
    <DashboardLayout>
      <div className="max-w-2xl mx-auto p-6">
        <div className="bg-white/50 dark:bg-slate-800/50 backdrop-blur-sm rounded-3xl shadow-lg p-6">
          <h1 className="text-2xl font-bold text-slate-800 dark:text-white mb-6 flex items-center gap-2">
            <FiUser className="w-6 h-6" />
            Yeni Personel Ekle
          </h1>

          <form onSubmit={handleSubmit} className="space-y-6">
            <div className="space-y-4">
              {/* Ad Soyad */}
              <div>
                <label className="block text-sm font-medium text-slate-700 dark:text-slate-300 mb-2">
                  Ad Soyad
                </label>
                <div className="relative">
                  <FiUser className="absolute left-3 top-1/2 -translate-y-1/2 w-5 h-5 text-slate-400 dark:text-slate-500" />
                  <input
                    type="text"
                    name="name"
                    required
                    className="w-full pl-10 pr-4 py-3 rounded-xl border border-slate-200 dark:border-slate-700 
                             bg-white dark:bg-slate-800 focus:ring-2 focus:ring-fuchsia-500/50 
                             text-slate-800 dark:text-slate-100 placeholder-slate-400 dark:placeholder-slate-500
                             transition-all duration-200"
                    value={formData.name}
                    onChange={(e) => setFormData({...formData, name: e.target.value})}
                  />
                </div>
              </div>

              {/* E-posta */}
              <div>
                <label className="block text-sm font-medium text-slate-700 dark:text-slate-300 mb-2">
                  E-posta
                </label>
                <div className="relative">
                  <FiMail className="absolute left-3 top-1/2 -translate-y-1/2 w-5 h-5 text-slate-400 dark:text-slate-500" />
                  <input
                    type="email"
                    required
                    className="w-full pl-10 pr-4 py-3 rounded-xl border border-slate-200 dark:border-slate-700 
                             bg-white dark:bg-slate-800 focus:ring-2 focus:ring-fuchsia-500/50 
                             text-slate-800 dark:text-slate-100 placeholder-slate-400 dark:placeholder-slate-500
                             transition-all duration-200"
                    value={formData.email}
                    onChange={(e) => setFormData({...formData, email: e.target.value})}
                  />
                </div>
              </div>

              {/* Şifre */}
              <div>
                <label className="block text-sm font-medium text-slate-700 dark:text-slate-300 mb-2">
                  Şifre
                </label>
                <div className="relative">
                  <FiLock className="absolute left-3 top-1/2 -translate-y-1/2 w-5 h-5 text-slate-400 dark:text-slate-500" />
                  <input
                    type="password"
                    required
                    minLength={6}
                    className="w-full pl-10 pr-4 py-3 rounded-xl border border-slate-200 dark:border-slate-700 
                             bg-white dark:bg-slate-800 focus:ring-2 focus:ring-fuchsia-500/50 
                             text-slate-800 dark:text-slate-100 placeholder-slate-400 dark:placeholder-slate-500
                             transition-all duration-200"
                    value={formData.password}
                    onChange={(e) => setFormData({...formData, password: e.target.value})}
                  />
                </div>
              </div>
              <div>
                <label className="block text-sm font-medium text-slate-700 dark:text-slate-300 mb-2">
                  Şifre Tekrarı
                </label>
                <div className="relative">
                  <FiLock className="absolute left-3 top-1/2 -translate-y-1/2 w-5 h-5 text-slate-400 dark:text-slate-500" />
                  <input
                    type="password"
                    required
                    minLength={6}
                    className="w-full pl-10 pr-4 py-3 rounded-xl border border-slate-200 dark:border-slate-700 
                             bg-white dark:bg-slate-800 focus:ring-2 focus:ring-fuchsia-500/50 
                             text-slate-800 dark:text-slate-100 placeholder-slate-400 dark:placeholder-slate-500
                             transition-all duration-200"
                    value={formData.password_confirmation}
                    onChange={(e) => setFormData({...formData, password_confirmation: e.target.value})}
                  />
                </div>
              </div>
            </div>

            <button
              type="submit"
              disabled={loading}
              className="w-full flex items-center justify-center gap-2 px-6 py-3.5 
                       text-white bg-gradient-to-r from-fuchsia-500 to-purple-500 
                       rounded-xl hover:opacity-90 disabled:opacity-50 transition-all 
                       font-medium shadow-lg"
            >
              <FiSave className="w-5 h-5" />
              {loading ? 'Kaydediliyor...' : 'Personel Ekle'}
            </button>
          </form>
        </div>

        {/* Hata ve Başarı Mesajları */}
        <Modal
          isOpen={!!error}
          onClose={() => setError(null)}
          title="Hata"
          message={error || ''}
        />
        <Modal
          isOpen={!!success}
          onClose={() => setSuccess(null)}
          title="Başarılı"
          message={success || ''}
        />
      </div>
    </DashboardLayout>
  )
} 